/**
 * Created by TFG on 06/29/20.
 *
 * This contains common code used by validation/loading for the AWCBL operations.
 */

var fs = require('fs');
var path = require('path');
var dateFormat = require('dateformat');

// Defines where the monitoring areas are
var loadingFileDir = process.env.MASTER_FILE || '/opt/fresenius/efs/sftp/bcdsupport/dropbox/';
var countFiles = process.env.COUNT_FILE || '/Users/will/dev/fresenius/fresenius-m3-api/components/data/counts/';

//
// ------------------- Exporting functions --------------------------------------
//

module.exports.formatPrice = formatPrice;
module.exports.formatDate = formatDate;
module.exports.getCatalogId = getCatalogId;
module.exports.getClinicId = getClinicId;
module.exports.getVendorId = getVendorId;
module.exports.getVendorDisplay = getVendorDisplay;
module.exports.getProductId = getProductId;
module.exports.getProductVendorId = getProductVendorId;
module.exports.loadClinicProfile = loadClinicProfile;
module.exports.loadMasterItems = loadMasterItems

module.exports.writeAwcblEntryLog = writeAwcblEntryLog;

//
// ------------------- Common functions - miscellaneus - other Bulk management -----------------------------
//

function formatPrice (csvPrice) {
  if (!csvPrice) {
    return csvPrice;
  }

  var flPrice;
  try {
    flPrice = parseFloat(csvPrice);
    return flPrice.toFixed(2);
  } catch (ex) {
    return "0.00";
  }
}

// The function receive a date or nothing
// If no date returns null, otherwise returns the date formatted in Iso standard.
function formatDate (inputDate) {
  if (inputDate.isEmpty || inputDate.length < 2) {
    return null;
  }

  var strDate = dateFormat(inputDate, "isoDate");
  return strDate;
}

// Function return a valid ID if the input catalog exists in the tbl_catalogs
// Returns -1 otherwise
function getCatalogId (app, allCatalogs, name) {
  var out = -1;
  if (allCatalogs && name) {
    for (var v = 0; v < allCatalogs.length; v++) {
      var vendor = allCatalogs[v];
      if (vendor.catalogId === name) {
        out = vendor.id;
        break;
      }
    }
  }
  return out;
}


// Function return a valid ID if the input clinicID exists in the tbl_clinic_profile
// Returns -1 otherwise
function getClinicId (allClinics, clinId) {
  var out = -1;
  if (allClinics && clinId) {
    for (var v = 0; v < allClinics.length; v++) {
      var record = allClinics[v];
      // The clinic ID Need to be verified without the initial dot and the alphanumeric part in the end
      // Extract the number only on both sides
      var dbClinicId = record.clinicId.match(/(\d+)/);
      var inputClinicId = clinId.match(/(\d+)/);

      if (dbClinicId[0] === inputClinicId[0]) {
        out = record.id;
        break;
      }
    }
  }
  return out;
}

// Function return a valid ID if the input vendorMaterial exists in the tbl_master_item
// Returns -1 otherwise
// The function return a valid ID on the FIRST finding !
// Duplicates are ignored at this stage
function getProductId (allProducts, vendMat) {
  var out = -1;
  if (allProducts && vendMat) {
    for (var v = 0; v < allProducts.length; v++) {
      var record = allProducts[v];
      if (record.vendorMaterial === vendMat) {
        out = record.id;
        break;
      }
    }
  }
  return out;
}

// Function return a valid vendor name if the input vendorID exists in the tbl_vendor_list table
// Returns -1 otherwise
function getVendorDisplay (allVendors, vendorId) {
  var out = -1;
  if (allVendors && vendorId) {
    for (var v = 0; v < allVendors.length; v++) {
      var record = allVendors[v];
      if (record.vendorId === vendorId) {
        out = record.vendorDisplay;
        break;
      }
    }
  }
  return out;
}


// Function return a valid ID if the input vendorID exists in the tbl_vendor_list table
// Returns -1 otherwise
function getVendorId (allVendors, vendorId) {
  var out = -1;
  if (allVendors && vendorId) {
    for (var v = 0; v < allVendors.length; v++) {
      var record = allVendors[v];
      if (record.vendorId === vendorId) {
        out = record.id;
        break;
      }
    }
  }
  return out;
}


// Function return the vandor_id for the id passed
// Returns -1 otherwise
function getProductVendorId (allProducts, id) {
  var out = "Invalid";
  if (allProducts && id) {
    for (var v = 0; v < allProducts.length; v++) {
      var record = allProducts[v];
      if (record.id === id) {
        out = record.vendorId;
        break;
      }
    }
  }
  return out;
}

// Load clinic profile for validation
function loadClinicProfile (app, debug) {
  var winston = app.get('winston');
  var logger = winston.loggers.get('main');
  var models = app.get('models');

  var all_clinics = [];

  models.ClinicProfile.findAll().then(function (clinics) {
    if (clinics) {
      if (debug === true) {
        logger.debug("loaded " + clinics.length + " Clinic Profiles");
      }

      all_clinics = clinics;
      return typeof all_clinics;
    } else {
      if (debug === true) {
        logger.error("No Clinic Profiles loaded");
      }
    }
  });
}

// Load master items for validation
function loadMasterItems (app, debug) {
  var winston = app.get('winston');
  var logger = winston.loggers.get('main');
  var models = app.get('models');

  var all_items = [];

  models.MasterItem.findAll().then(function (items) {
    if (items) {
      if (debug === true) {
        logger.debug("loaded " + items.length + " Master Items");
      }
      all_items = items;
      return typeof all_items;
    } else {
      if (debug === true) {
        logger.error("No Master Items loaded");
      }
    }
  });
}

// Write AWCBL LOg entry record from here
function writeAwcblEntryLog (app, path, transaction_id, status, notes) {
  return new Promise(function (resolve, reject) {
    var winston = app.get('winston');
    var logger = winston.loggers.get('main');
    var models = app.get('models');

    var record = { userName: "", reportPath: "", status: "", transactionId: "", notes: "", date: 0 };
    record.date = new Date();
    record.username = "m3-loader";
    record.reportPath = path;
    record.transactionId = transaction_id;
    record.status = status;
    record.notes = notes;

//    logger.debug("writeAwcblEntryLog called - record: " + JSON.stringify(record, null, 4));

    try {
      models.AwcblLog.findOrCreate({
        where: {
          id: 0
        }, defaults: {
          userId: record.username,
          reportPath: record.reportPath,
          transactionId: record.transactionId,
          status: record.status,
          notes: record.notes,
          date: record.date
        }
      }).spread(function (data, created) {
        if (!created) {
          // Assign the data received in input (record)
          data.userId = record.username;
          data.reportPath = record.reportPath;
          data.transactionId = record.transactionId;
          data.status = record.status;
          data.notes = record.notes;
          data.date = record.date;

          data.save().then(function () {
            // Operation successfull
          }).catch(function (err) {
            // Operation failed
            reject("writeAwcblEntryLog - failed to update record " + err);
          });
        } else {
          // Operation successful - new record, should have assigned the record
        }
        resolve("writeAwcblEntryLog - OK");
      }).catch(function (err) {
        // Problems
        reject("writeAwcblEntryLog - inner SQL error " + err);
      });
    } catch (err) {
      reject("writeAwcblEntryLog - outer SQL error " + err);
    }
  });
}
