/**
 * Created by John on 7/5/2017.
 * Modified by TFG on 7/21/2020.
 *
 * Common logic for manipulating Loader models
 *
 * CAUTION !  each load now has a common starting base :
 *    csv_line[0] -> transactionId
 *    csv_line[1] -> file name
 *    csv_line[2] -> expected number of messages
 */

// CAUTION !
// call from this module the common functions without passing the app or system settings, it will not work
// app or winston or logger will cause the common function just to don't work, NO ERRORS ISSUED BY THE SYSTEM !

var express = require('express');
var app = express();
//var app = require("../../child");

var awcblcommon = require('../config/awcblcommon');

var debug = false;               // Flag used to enable extra log messages for debug/problem solving

var moment = require("moment");
if (!String.prototype.startsWith) {
    String.prototype.startsWith = function(searchString, position) {
        position = position || 0;
        return this.indexOf(searchString, position) === position;
    };
}


function LoaderHelper(models, winston) {
    this.models = models;
    this.winston = winston
    this.logger = null;
    if (this.winston) {
        this.logger = this.winston.loggers.get("main");
    } else {
        this.logger = console;
        if (!this.logger.debug) this.logger.debug = console.log;
    }
}

/**
 * Saves a single Clinic Routing  record to the database tbl_vendor_route_clinic via promise
 * IMPORTANT ! It is assumed the data coming here are already vetted by m3-api during the
 * validation !!!!!!
 * It means no specific check on the data are performed here !
 * Expected CSV format :
 *   - transactionID
 *   - file_name
 *   - Number_messages
 *   - clinicId
 *   - vendorId
 *   - route
 *   - vendorDisplay
 *
 * @param {Object} msg JSON from Http
 */
LoaderHelper.prototype.saveLoaderCR = function(msg) {
    var self = this;
    var startingCSVindex = 3;

    return new Promise(function (resolve, reject) {
        var inClinicId;                 // Input clinic ID
        var inVendorId;                 // Input vendor ID
        var inPathRoute;                // Input Path route
        var inVendorDisplay;            // Input vendor display

        var csv_line = msg.split(/,(?=(?:(?:[^"]*"){2})*[^"]*$)/);
        csv_line = csv_line || [];

        if (csv_line.length > 1) {
            try {
                inClinicId = csv_line[startingCSVindex].split(',').join('');   // Assign input Clinic ID
                inVendorId = csv_line[startingCSVindex+1].split(',').join('');   // Assign input Vendor ID
                inPathRoute = csv_line[startingCSVindex+2].split(',').join('');   // Assign Path route
                // Extra parameter not in the original CSV file
                inVendorDisplay = csv_line[startingCSVindex+3].split(',').join('');   // Assign Vendor display name
            } catch (err) {
                // The test is needed in case the CSV record received is just the original one from the
                // bulk load CSV file, without the two extra parameters
                if (inVendorDisplay === undefined) {
                    inVendorDisplay = "--";
                } else {
                    reject("CAUTION !! CR - wrong CSV format received : " + err);
                }
            }

            if (debug === true) {
                self.logger.debug("  Payload retrieved ");
                self.logger.debug("           clinicID : " + inClinicId);  // Clinic ID
                self.logger.debug("           vendorId : " + inVendorId);  // Vendor Id
                self.logger.debug("          pathRoute : " + inPathRoute);  // Path route
                self.logger.debug("      vendorDisplay : " + inVendorDisplay);  // Vendor name
            }

            // TEMP ! Caution on the VendorDisplay

            self.models.VendorRouteClinic.findOrCreate({
                where: {
                    clinicId: inClinicId,
                    vendorId: inVendorId
                }, defaults: {
                    vendorDisplay: inVendorDisplay,
                    vendorPathRoute: inPathRoute
                    // no other parameters for default as the three above
                }
            }).spread(function (data, created) {
                if (!created) {
                    // Update record
//                    data.clinicId = inClinicId;
//                    data.vendorId = inVendorId;
                    data.vendorPathRoute = inPathRoute;

                    data.save().then(function () {
                        if (debug === true) {
                            self.logger.debug("Record updated ");
                        }
                        // Record updated successfully
                    }).catch(function (err) {
                        reject("CR - problem interacting with DB : " + err);
                    });
                } else {
                    // Record created successfully
                    if (debug === true) {
                        self.logger.debug("Record created ");
                    }
                }
                resolve("OK");
            }).catch(function (err) {
                reject("CR Error handling table : " + err);
            });
        } else {
            // Should never happens !!
            reject("CAUTION !! CR - something wrong received ! ");
        }
    });
};

/**
 * Saves a single Par Value record to the database tbl_sap_item_par_value via promise
 * IMPORTANT ! It is assumed the data coming here are already vetted by m3-api during the
 * validation !!!!!!
 * It means no specific check on the data are performed here !
 * Expected CSV format :
 *   - transactionID
 *   - file_name
 *   - Number_messages
 *   - clinicId
 *   - productId
 *   - qoh
 *   - min_par
 *   - max_par
 *   - vendorId
 *   - productName
 *
 * @param {Object} msg JSON from Http
 */
LoaderHelper.prototype.saveLoaderPV = function(msg) {
    var self = this;
    var startingCSVindex = 3;

    return new Promise(function (resolve, reject) {
        var inClinicId;                 // Input clinic ID
        var inProductId;                // Input product ID
        var inQoh;                      // Input QOH value
        var inMinParValue;              // Input Min par value
        var inMaxParValue;              // Input Max par value
        var inVendorId;                 // Input vendor ID
        var inProductName;              // Input product display name

        var csv_line = msg.split(/,(?=(?:(?:[^"]*"){2})*[^"]*$)/);
        csv_line = csv_line || [];

        if (csv_line.length > 1) {
            // Received something - check if is the information record
            try {
                // Prepare the fields to be loaded in the table reading the received record in the queue
                inClinicId = csv_line[startingCSVindex].split(',').join('');   // Assign input Clinic ID
                inProductId = csv_line[startingCSVindex+1].split(',').join('');   // Assign input Product ID
                inQoh = csv_line[startingCSVindex+2].split(',').join('');   // Assign input QOH
                inMinParValue = csv_line[startingCSVindex+3].split(',').join('');   // Assign input MinParValue
                inMaxParValue = csv_line[startingCSVindex+4].split(',').join('');   // Assign input MaxParValue
                // Extra parameters not in the original CSV file
                inVendorId = csv_line[startingCSVindex+5].split(',').join('');   // Assign input vendorId
                inProductName = csv_line[startingCSVindex+6].split(',').join('');   // Assign input Product Name
            } catch (err) {
                // The test is needed in case the CSV record received is just the original one from the
                // bulk load CSV file, without the two extra parameters
                if (inVendorId === undefined || inProductName === undefined) {
                    inVendorId = "--";
                    inProductName = "--";
                } else {
                    reject("CAUTION !! PV - wrong CSV format received : " + err);
                }
            }

            if (debug === true) {
                self.logger.debug("  Payload retrieved ");
                self.logger.debug("           clinicID : " + inClinicId);  // Clinic ID
                self.logger.debug("          productId : " + inProductId);  // Product ID
                self.logger.debug("                QOH : " + inQoh);  // QOH
                self.logger.debug("      min Par value : " + inMinParValue);  // Min
                self.logger.debug("      max Par value : " + inMaxParValue);  // Max
                self.logger.debug("           vendorId : " + inVendorId);  // Vendor Id
                self.logger.debug("        productName : " + inProductName);  // Product Name
            }

            self.models.VendorSapParValue.findOrCreate({
                where: {
                    vendorMaterial: inProductId,
                    vendorId: inVendorId,
                    clinicId: inClinicId
                }, defaults: {
                    qohValue: inQoh,
                    minParValue: inMinParValue,
                    maxParValue: inMaxParValue,
                    description: inProductName
                }
            }).spread(function (data, created) {
                if (!created) {
//                    data.vendorMaterial = inProductId;
//                    data.vendorId = inVendorId;
//                    data.clinicId = inClinicId;
                    data.qohValue = inQoh;
                    data.minParValue = inMinParValue;
                    data.maxParValue = inMaxParValue;
                    data.description = inProductName;

                    data.save().then(function () {
                        // Update successfull
                        if (debug === true) {
                            self.logger.debug("Record updated ");
                        }
                    }).catch(function (err) {
                        reject("PV - problem interacting with DB : " + err);
                    });
                } else {
                    // Creation successfull
                    if (debug === true) {
                        self.logger.debug("Record created ");
                    }
                }
                resolve("OK");
            }).catch(function (err) {
                reject("PV Error handling table : " + err);
            });
        } else {
            reject("CAUTION !! PV - something wrong received ! ");
        }
    });
};

/**
 * Saves a single Clinic Profile record to the database tbl_clinic_profile via promise
 * IMPORTANT ! It is assumed the data coming here are already vetted by m3-api during the
 * validation !!!!!!
 * It means no specific check on the data are performed here !
 * Expected CSV format :
 *   - transactionID
 *   - file_name
 *   - Number_messages
 *   - clinic_id
 *   - test_catalog
 *   - Mircera_visible
 *   - Mircera_Io
 *   - Areanesp_visible
 *   - Areanesp_Io
 *   - Epogen_Visible
 *   - Epogen_Io
 *   - Retacrit_visible
 *   - Retacrit_Io
 *   - Count_each_in
 *
 * @param {Object} msg JSON from Http
 */
LoaderHelper.prototype.saveLoaderCP = function(msg) {
    var self = this;
    var startingCSVindex = 3;

    return new Promise(function (resolve, reject) {
        var clinicIdId;
        var inClinicId;                 // Input clinic ID
        //var inTestCatalog;
        var inMirceraVisible;
        var inMirceraIo;
        var inAreanespVisible;
        var inAreanespIo;
        var inEpogenVisible;
        var inEpogenIo;
        var inRetacritVisible;
        var inRetacritIo;
        var inCountInEach;
        var inDateModified;

        var csv_line = msg.split(/,(?=(?:(?:[^"]*"){2})*[^"]*$)/);
        csv_line = csv_line || [];

        if (debug === true) {
            self.logger.debug("saveLoaderCP - csv line             : " + JSON.stringify(csv_line));
        }

        // NOTE !
        // The inTestCatalog is ALREADY a list of catalogs ID separated by the character #
        // Validation takes care also of the case of no catalog presents.
        // Has no use here since is used before to create the clinicCatalog list associated to this record

        if (csv_line.length > 1) {
            try {
                // Prepare the fields to be loaded in the table reading the received record in the queue
                inClinicId = csv_line[startingCSVindex].split(',').join('');
                //inTestCatalog = csv_line[startingCSVindex+1].split('"').join('');
                inMirceraVisible = csv_line[startingCSVindex+2].split('"').join('');
                inMirceraIo = csv_line[startingCSVindex+3].split('"').join('');
                inAreanespVisible = csv_line[startingCSVindex+4].split('"').join('');
                inAreanespIo = csv_line[startingCSVindex+5].split('"').join('');
                inEpogenVisible = csv_line[startingCSVindex+6].split('"').join('');
                inEpogenIo = csv_line[startingCSVindex+7].split('"').join('');
                inRetacritVisible = csv_line[startingCSVindex+8].split('"').join('');
                inRetacritIo = csv_line[startingCSVindex+9].split('"').join('');
                inCountInEach = csv_line[startingCSVindex+10].split('"').join('');
                inDateModified = new Date();
            } catch (e) {
                self.logger.error("Catch error : " + JSON.stringify(e));
                reject("CAUTION !! CP - wrong CSV format received ! ");
            }

            if (debug === true) {
                self.logger.debug("  Payload retrieved ");
                self.logger.debug("           clinicID : " + inClinicId);
                //self.logger.debug("      inTestCatalog : " + inTestCatalog);
                self.logger.debug("   inMriceraVisible : " + inMirceraVisible);
                self.logger.debug("        inMriceraIo : " + inMirceraIo);
                self.logger.debug("  inAreanespVisible : " + inAreanespVisible);
                self.logger.debug("       inAreanespIo : " + inAreanespIo);
                self.logger.debug("    inEpogenVisible : " + inEpogenVisible);
                self.logger.debug("         inEpogenIo : " + inEpogenIo);
                self.logger.debug("  inRetacritVisible : " + inRetacritVisible);
                self.logger.debug("       inRetacritIo : " + inRetacritIo);
                self.logger.debug("      inCountInEach : " + inCountInEach);
                self.logger.debug("     inDateModified : " + inDateModified);
            }

            // Building an object with the data received in input
            // Not saving on DB the vendorList (is a virtual field)
            var clinicProfile = self.models.ClinicProfile.build({
                clinicId: inClinicId,
                //vendorList: inTestCatalog,
                mirceraVisible: inMirceraVisible === 'y',
                mirceraIo: inMirceraIo === 'y',
                areanespVisible: inAreanespVisible === 'y',
                areanespIo: inAreanespIo === 'y',
                epogenVisible: inEpogenVisible === 'y',
                epogenIo: inEpogenIo === 'y',
                retacritVisible: inRetacritVisible === 'y',
                retacritIo: inRetacritIo === 'y',
                countInEach: inCountInEach === 'y',
                dateModified: inDateModified
            });

            self.models.ClinicProfile.findOrCreate({
                where: {
                    clinicId: inClinicId
                }, defaults: {
                    clinicProfile
                }
            }).spread(function (data, created) {
                clinicIdId = data.id;      // Save record ID
                if (!created) {
                    data.clinicId = clinicProfile.clinicId;
                    //data.vendorList = clinicProfile.vendorList;
                    data.mirceraVisible = clinicProfile.mirceraVisible;
                    data.mirceraIo = clinicProfile.mirceraIo;
                    data.areanespVisible = clinicProfile.areanespVisible;
                    data.areanespIo = clinicProfile.areanespIo;
                    data.epogenVisible = clinicProfile.epogenVisible;
                    data.epogenIo = clinicProfile.epogenIo;
                    data.retacritVisible = clinicProfile.retacritVisible;
                    data.retacritIo = clinicProfile.retacritIo;
                    data.countInEach = clinicProfile.countInEach;
                    data.dateModified = clinicProfile.dateModified;

                    data.save().then(function () {
                        if (debug === true) {
                            self.logger.debug("   updated CP record " + data.id);
                        }
                        // TBD ? Update tbl_clinic_catalog
                    }).catch(function (err) {
                        reject("CP - problem interacting with DB : " + err);
                    });
                } else {
                    if (debug === true) {
                        self.logger.debug("   created CP record " + data.id);
                    }
                }
                // Bring back the table ID of the saved/updated record !
                resolve(clinicIdId);
            }).catch(function (err) {
                reject("CP Error handling table : " + err);
            });
        } else {
            reject("CAUTION !! CP - something wrong received ! ");
        }
    });
};

/**
 * Remove from the tbl_clinic_catalog all the entries related to a specific clinic ID
 *
 * @param clinic ID ID    (the ID in the tbl_clinic_profile of a clinic ID
 */
LoaderHelper.prototype.removeCPassociated = function(inClinicIdId) {
    var self = this;

    return new Promise(function (resolve, reject) {
        if (debug === true) {
            self.logger.debug("removeCPassociated for " + inClinicIdId);
        }

        // Remove from the table all entries related to the clinicId received
        self.models.ClinicCatalog.destroy({
            where: {
                clinicId: inClinicIdId
            }
        }).then(function (num) {
            // Removed entries
            if (debug === true) {
                self.logger.debug("  --> removed clinic_id (id) " + inClinicIdId + " entries");
            }
            resolve("OK ");

        }).catch(function (delErr) {
            reject("CP associated Error - unable to clean up old data : " + delErr);
        });
    });
};


/**
 * Saves a an associated list of clinic catalog objects to the database tbl_clinic_catalog via promise
 * The input is an object of records
 *
 * @param clinic ID ID    (the ID in the tbl_clinic_profile of a clinic ID
 * @param catalog ID
 */
LoaderHelper.prototype.saveCPassociatedEntry = function(inClinicIdId, inCatalogId) {
    var self = this;

    return new Promise(function (resolve, reject) {
        self.logger.info("saveCPassociatedEntry for " + inClinicIdId + " : " + inCatalogId);

        // Save new list in database !

        self.models.ClinicCatalog.findOrCreate({
            where: {
//                clinicId: inClinicIdId
                id: 0               // This to force to create always a new record !
            }, defaults: {
                clinicId: inClinicIdId,
                catalogId: inCatalogId
            }
        }).spread(function (data, created) {
            if (!created) {
                data.clinicId = inClinicIdId;
                data.catalogId = inCatalogId;

                data.save().then(function () {
                    if (debug === true) {
                        self.logger.debug("  --> updated associated entry for clinic_id (id) " + inClinicIdId + " - catalogId : " + data.catalogId);
                    }
                }).catch(function (err) {
                    reject("CP associated record - problem interacting with DB : " + err);
                });
            } else {
                if (debug === true) {
                    self.logger.debug("  --> created associated entry for clinic_id (id) " + inClinicIdId + " - catalogId : " + data.catalogId);
                }
            }
            resolve("OK");
        });
    });
};

/**
 * Saves a single Master Item record to the database tbl_master_item via promise
 * IMPORTANT ! It is assumed the data coming here are already vetted by m3-api during the
 * validation !!!!!!
 * It means no specific check on the data are performed here !  (note - FRES-192 removed the ndc)
 * Expected CSV format - position on csv_line :
 *   - transactionID    [0]
 *   - file_name        [1]
 *   - Number_messages  [2]
 *   - sap_material     [3]
 *   - description      [4]
 *   - cnt_ind          [5]
 *   - cnt_description  [6]
 *   - med_vendor       [7] (index, not description, separation is # - not used here!!)
 *   - vendor_material  [8]
 *   - conv             [9]
 *   - count_type       [10]
 *   - alternates       [11]
 *   - unit_price       [12]
 *   - vendor_id        [13]
 *   - onhand_inventory_ind [14]
 *   - discontinued     [15]
 *
 * @param {Object} msg JSON from Http
 */
LoaderHelper.prototype.saveLoaderMT = function(msg) {
    var self = this;
    var startingCSVindex = 3;

    return new Promise(function (resolve, reject) {
        var itemIdId;
        var csv_line = msg.split(/,(?=(?:(?:[^"]*"){2})*[^"]*$)/);
        csv_line = csv_line || [];

        if (debug === true) {
            self.logger.debug("saveLoaderMT - csv line --> " + JSON.stringify(csv_line));
        }

        if (csv_line.length > 1) {
            try {
                // Building an object with the data received in input to update the tbl_master_item
                var masterItem = self.models.MasterItem.build({
                    sapMaterial: parseInt(csv_line[startingCSVindex]),
                    description: csv_line[startingCSVindex+1].split('"').join(''),
                    cntInd: csv_line[startingCSVindex+2].split('"').join('')  === 'X',
                    cntDescription: csv_line[startingCSVindex+3].split('"').join(''),
                    vendorMaterial: csv_line[startingCSVindex+5].split('"').join(''),
                    conv: parseInt(csv_line[startingCSVindex+6].split('"').join('')),
                    countType: csv_line[startingCSVindex+7].split('"').join(''),
                    alternates: csv_line[startingCSVindex+8].split('"').join(''),
                    unitPrice: awcblcommon.formatPrice(csv_line[startingCSVindex+9].split('"').join('')),
                    vendorId: csv_line[startingCSVindex+10].split('"').join(''),
                    ndc: null,
                    showInventoryInd: csv_line[startingCSVindex+11].split('"').join('')  === 'X',
                    discontinued: awcblcommon.formatDate(csv_line[startingCSVindex+12].split('"').join('')),
                    dateModified: new Date()
                });

                if (isNaN(masterItem.conv)) {
                    masterItem.conv = 1;
                }

                if (debug === true) {
                    self.logger.debug("  Payload retrieved ");
                    self.logger.debug("      sapMaterial : " + masterItem.sapMaterial);
                    self.logger.debug("      description : " + masterItem.description);
                    self.logger.debug("           cntInd : " + masterItem.cntInd);
                    self.logger.debug("   cntDescription : " + masterItem.cntDescription);
                    self.logger.debug("   vendorMaterial : " + masterItem.vendorMaterial);
                    self.logger.debug("             conv : " + masterItem.conv);
                    self.logger.debug("        countType : " + masterItem.countType);
                    self.logger.debug("       alternates : " + masterItem.alternates);
                    self.logger.debug("        unitPrice : " + masterItem.unitPrice);
                    self.logger.debug("         vendorId : " + masterItem.vendorId);
                    self.logger.debug("              ndc : " + masterItem.ndc);   // MUST BE FORCED NULL !
                    self.logger.debug(" showInventoryInd : " + masterItem.showInventoryInd);
                    self.logger.debug("     discontinued : " + masterItem.discontinued);
                    self.logger.debug("     dateModified : " + masterItem.dateModified);
                }

                // Update the master item table - original way on old bulk load procedure
                // CAUTION ! TFG note
                // Apparently using the dataValues to update the master item record, ANY field set to null is NOT
                // included in the update.
                // This means that for example the field discontinued CAN NOT BE REVERSED from a bulk load.
                // If the field discontinued is set to null, because not present in the CSV record, it will NOT be
                // updated, thus if is discontinued in the db (date present) will continue to remains discontinued !
                // At the current date/release the ONLY way to reverse the discontinued record is going MANUALLY
                // on the DB and forcing null the discontinued field of the record !
                // Also from the UI there is not way to do !
                // Putting a warning log for documentation
                if (masterItem.discontinued === null) {
                    self.logger.warn("WARNING! discontinued field for sap_material_id " + masterItem.sapMaterial + " is null. No actually update on this field in the DB");
                }

                // FRES-192 warning ! Just in case, should NEVER happens !
                if (masterItem.ndc !== null) {
                    self.logger.warn("WARNING! ndc field for sap_material_id " + masterItem.sapMaterial + " is NOT null. Something very wrong here ");
                }

                self.models.MasterItem.findOrCreate({
                    where: {
                        sapMaterial: masterItem.sapMaterial,
                        vendorMaterial: masterItem.vendorMaterial
                    }, raw: true, paranoid: false
                }).spread(function (itemRecord, created) {
                    masterItem.id = itemRecord.id;
                    itemIdId = itemRecord.id;      // Save record ID

                    self.models.MasterItem.update(masterItem.dataValues, { where: { id: masterItem.id } })
                        .then(function (count) {
                            if (debug === true) {
                                self.logger.debug("Master Item " + ((created) ? "created" : "updated") + " by ftp sync: " + JSON.stringify(masterItem));
                            }
                            // Bring back the table ID of the saved/updated record !
                            resolve(itemIdId);
                        }).catch(function (upderr) {
                        reject("MT Error handling table on update : " + upderr);
                    });
                }).catch(function (err) {
                    reject("MT Error handling table on findOrCreate : " + err);
                });

            } catch (e) {
                self.logger.error("Catch error while formatting MT object : " + JSON.stringify(e));
                reject("CAUTION !! MT - wrong CSV format received ! ");
            }

        } else {
            reject("CAUTION !! MT  - something wrong received ! ");
        }
    });
};

/**
 * Remove from the tbl_item_catalog all the entries related to a specific item ID
 *
 * @param item ID ID    (the ID in the tbl_master_item of a item ID
 */
LoaderHelper.prototype.removeMTassociated = function(inItemIdId) {
    var self = this;

    return new Promise(function (resolve, reject) {
        if (debug === true) {
            self.logger.debug("removeMTassociated for " + inItemIdId);
        }

        // Remove from the table all entries related to the clinicId received
        self.models.ItemCatalog.destroy({
            where: {
                itemId: inItemIdId
            }
        }).then(function (num) {
            // Removed entries
            if (debug === true) {
                self.logger.debug("  --> removed item_id (id) " + inItemIdId + " entries");
            }
            resolve("OK ");

        }).catch(function (delErr) {
            reject("MT associated Error - unable to clean up old data : " + delErr);
        });
    });
};


/**
 * Saves a an associated list of item catalog objects to the database tbl_item_catalog via promise
 * The input is an object of records
 *
 * @param item ID ID    (the ID in the tbl_master_item of a item ID
 * @param catalog ID
 */
LoaderHelper.prototype.saveMTassociatedEntry = function(inItemIdId, inCatalogId) {
    var self = this;

    return new Promise(function (resolve, reject) {
        self.logger.info("saveMTassociatedEntry for " + inItemIdId + " : " + inCatalogId);

        // Save new list in database !

        self.models.ItemCatalog.findOrCreate({
            where: {
                id: 0               // This to force to create always a new record !
            }, defaults: {
                itemId: inItemIdId,
                catalogId: inCatalogId
            }
        }).spread(function (data, created) {
            if (!created) {
                data.itemId = inItemIdId;
                data.catalogId = inCatalogId;

                data.save().then(function () {
                    if (debug === true) {
                        self.logger.debug("  --> updated associated entry for item_id (id) " + inItemIdId + " - catalogId : " + data.catalogId);
                    }
                }).catch(function (err) {
                    reject("MT associated record - problem interacting with DB : " + err);
                });
            } else {
                if (debug === true) {
                    self.logger.debug("  --> created associated entry for item_id (id) " + inItemIdId + " - catalogId : " + data.catalogId);
                }
            }
            resolve("OK");
        });
    });
};


module.exports = LoaderHelper;
